@@ -47,7 +47,6 @@
 int NumLockMask, CapsLockMask, ScrollLockMask;
 
 gboolean gail_loaded = FALSE;
-GtkWidget *bah_window = NULL;
 
 gchar *
 gkb_load_pref(const gchar * key, const gchar * defaultv);
@@ -396,32 +395,35 @@ loadprop (int i)
 {
   GkbKeymap *actdata;
   gchar *buf;
+  gchar *default_cmd;
 
   actdata = g_new0 (GkbKeymap, 1);
 
 
-  buf = g_strdup_printf (_("name_%d"),i);
+  buf = g_strdup_printf ("name_%d",i);
   actdata->name = gkb_load_pref (buf, (i?"US 105 key keyboard":"Gnome Keyboard default"));
   g_free (buf);
 
-  buf = g_strdup_printf (_("label_%d"), i);
+  buf = g_strdup_printf ("label_%d", i);
   actdata->label = gkb_load_pref (buf, (i?"us":"gkb"));
   g_free (buf);
   
-  buf = g_strdup_printf (_("country_%d"), i);
+  buf = g_strdup_printf ("country_%d", i);
   actdata->country = gkb_load_pref (buf, (i?"United States":"Gnome Keyboard"));
   g_free (buf);
   
-  buf = g_strdup_printf (_("lang_%d"), i);
+  buf = g_strdup_printf ("lang_%d", i);
   actdata->lang = gkb_load_pref (buf, (i?"English":"International"));
   g_free (buf);
   
-  buf = g_strdup_printf (("flag_%d"), i);
+  buf = g_strdup_printf ("flag_%d", i);
   actdata->flag = gkb_load_pref (buf, (i?"us.png":"gkb.png"));
   g_free (buf);
   
-  buf = g_strdup_printf (_("command_%d"), i);
-  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap us":"xmodmap ~/.gkb_default.xmm"));
+  buf = g_strdup_printf ("command_%d", i);
+  default_cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ()); 
+  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap us":default_cmd));
+  g_free (default_cmd);
   g_free(buf);
 
   actdata->pixbuf = NULL;
@@ -434,11 +436,18 @@ static void
 do_at_first_run (GKB * gkb) 
 {
  gboolean firstrun;
+ gchar *cmd;
  firstrun = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), 
                                       "first_run", NULL);
- if ((firstrun == NULL) || (!firstrun)) {
-  system ("echo \"! This file has generated by Gnome Keyboard applet\" > ~/.gkb_default.xmm");
-  system ("xmodmap -pke >> ~/.gkb_default.xmm");
+ if (!firstrun) {
+  cmd = g_strdup_printf ("echo \"! This file has generated by Gnome Keyboard applet\" > %s/.gkb_default.xmm", g_get_home_dir ());
+  system (cmd);
+  g_free (cmd);
+
+  cmd = g_strdup_printf ("xmodmap -pke >> %s/.gkb_default.xmm", g_get_home_dir ());
+  system (cmd);
+  g_free (cmd);
+
   gconf_applet_set_bool (PANEL_APPLET (gkb->applet), "first_run", FALSE, NULL);
  }
  
@@ -613,7 +622,7 @@ about_cb (BonoboUIComponent *uic,
   link = gnome_href_new ("http://projects.gnome.hu/gkb",
 			 _("GKB Home Page (http://projects.gnome.hu/gkb)"));
 
-  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox), link, TRUE,
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about)->vbox), link, TRUE,
 		      FALSE, 0);
 
   if (pixbuf)
@@ -749,12 +758,21 @@ static const BonoboUIVerb gkb_menu_verbs [] = {
 };
 
 static void gkb_destroy (GtkWidget * widget, gpointer data) {
+	gchar *cmd;
+
+	/* restore the default keymap before exiting */
+	cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ());
+	system (cmd);
+	g_free (cmd);
+
 	g_free(gkb);
 }
 
 gboolean fill_gkb_applet(PanelApplet *applet)
 {
+  GdkWindow *root_window;
   gint keycode, modifiers;
+
   gkb = g_new0 (GKB, 1);
 
   gkb->n = 0;
@@ -764,12 +782,6 @@ gboolean fill_gkb_applet(PanelApplet *applet)
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gkb.png");
   
   panel_applet_add_preferences (applet, "/schemas/apps/gkb-applet/prefs", NULL);
-  /* FIXME: is bah_window needed for anything */
-  bah_window = gtk_window_new (GTK_WINDOW_POPUP);
-
-  gtk_widget_set_uposition (bah_window, gdk_screen_width () + 1,
-			    gdk_screen_height () + 1);
-  gtk_widget_show (bah_window);
 
   do_at_first_run(gkb);
 
@@ -785,10 +797,11 @@ gboolean fill_gkb_applet(PanelApplet *applet)
   keycode = XKeysymToKeycode(GDK_DISPLAY(), gkb->keysym);
 
   modifiers = gkb->state;
-  
-  gkb_xgrab (keycode, modifiers);
 
-  gdk_window_add_filter (GDK_ROOT_PARENT (), event_filter, NULL);
+  root_window = gdk_get_default_root_window ();
+
+  gkb_xgrab (keycode, modifiers, root_window);
+  gdk_window_add_filter (root_window, event_filter, NULL);
 
   g_signal_connect (G_OBJECT(gkb->applet),
   			  "destroy", 
