@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_ABOUT_H_
 #define __GWEATHER_ABOUT_H_
 
-/* $Id: gweather-about.h,v 1.3 2002/01/22 23:15:28 kevinv Exp $ */
+/* $Id: gweather-about.h,v 1.3.2.1 2002/07/10 23:48:58 mmclouglin Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -13,9 +13,11 @@
  *
  */
 
+#include "gweather.h"
+
 G_BEGIN_DECLS
 
-extern void gweather_about_run (void);
+extern void gweather_about_run (GWeatherApplet *gw_applet);
 
 G_END_DECLS
 
