@@ -62,18 +62,27 @@ command_key_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 
     /* printf("%d,%d,%d;  ", (gint16) event->keyval, event->state, event->length); */
 
-    if((key == GDK_Tab
+    if(key == GDK_Tab
        || key == GDK_KP_Tab
        || key == GDK_ISO_Left_Tab)
-       && event->state != GDK_SHIFT_MASK
-       && event->state != GDK_CONTROL_MASK)
-	{	
-	    /* tab key pressed */
-	    strcpy(buffer, (char *) gtk_entry_get_text(GTK_ENTRY(widget)));
-	    cmd_completion(buffer, applet);
-	    gtk_entry_set_text(GTK_ENTRY(widget), (gchar *) buffer);
+        {
+            if(event->state == GDK_CONTROL_MASK)
+                {
+                    /*
+                     * Move focus to the next widget (browser) button.
+                     */
+                    gtk_widget_child_focus (GTK_WIDGET (applet), GTK_DIR_TAB_FORWARD);
+	            propagate_event = FALSE;
+                }
+            else if(event->state != GDK_SHIFT_MASK)
+	        {	
+	                    /* tab key pressed */
+	            strcpy(buffer, (char *) gtk_entry_get_text(GTK_ENTRY(widget)));
+	            cmd_completion(buffer, applet);
+	            gtk_entry_set_text(GTK_ENTRY(widget), (gchar *) buffer);
 
-	    propagate_event = FALSE;
+	            propagate_event = FALSE;
+	        }
 	}
     else if(key == GDK_Up
 	    || key == GDK_KP_Up
@@ -155,17 +164,7 @@ command_key_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 		}	    
 	}
     
-
-    if(propagate_event == FALSE)
-	{
-	    /* I have to do this to stop gtk from propagating this event;
-	       error in gtk? */
-	    event->keyval = GDK_Right;
-	    event->state = 0;
-	    event->length = 0;  
-	}
     return (propagate_event == FALSE);
-    data = NULL;
 }
 
 #if 0
@@ -208,9 +207,6 @@ command_line_activate_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 #endif
     /* go on */
     return (FALSE);
-    widget = NULL;
-    event = NULL;
-    data = NULL;
 }
 
 #if 0
@@ -247,7 +243,6 @@ history_popup_clicked_cb(GtkWidget *widget, gpointer data)
      
     /* go on */
     return (FALSE);
-    data = NULL;
 }
 
 static gint
@@ -255,8 +250,6 @@ history_popup_clicked_inside_cb(GtkWidget *widget, gpointer data)
 {
     /* eat signal (prevent that popup will be destroyed) */
     return(TRUE);
-    widget = NULL;
-    data = NULL;
 }
 
 static gboolean
@@ -331,10 +324,10 @@ history_list_button_press_cb (GtkWidget *widget, GdkEventButton *event, gpointer
     return FALSE;
 }
 
-gint 
-show_history_signal(GtkWidget *widget, gpointer data)
+int 
+show_history_signal (GtkWidget   *widget,
+		     PanelApplet *applet)
 {
-     PanelApplet *applet = data;
      properties *prop = g_object_get_data (G_OBJECT (applet), "prop");
      GtkWidget *window;
      GtkWidget *frame;
@@ -355,14 +348,6 @@ show_history_signal(GtkWidget *widget, gpointer data)
 	 if(exists_history_entry(i))
 	     j++;
 
-     if(j == 0)
-	 {
-	     show_message((gchar *) _("history list empty"));
-
-	     /* don't show history popup window; go on */
-	     return FALSE;  	     
-	 }
-     
      window = gtk_window_new(GTK_WINDOW_POPUP); 
      gtk_window_set_policy(GTK_WINDOW(window), 0, 0, 1);
      /* cb */
@@ -400,16 +385,21 @@ show_history_signal(GtkWidget *widget, gpointer data)
      store = gtk_list_store_new (1, G_TYPE_STRING);
 
      /* add history entries to list */
-     for(i = 0; i < LENGTH_HISTORY_LIST; i++)
-	 {
-	     if(exists_history_entry(i))
-		 {
-		     command_list[0] = get_history_entry(i);
-                     gtk_list_store_append (store, &iter);
-                     gtk_list_store_set (store, &iter,0,command_list[0],-1);
+     if (j == 0) {
+          gtk_list_store_append (store, &iter);
+          gtk_list_store_set (store, &iter,0, "no items in history", -1);
+     }
+     else {	
+          for(i = 0; i < LENGTH_HISTORY_LIST; i++)
+	      {
+     	     if(exists_history_entry(i))
+	     	 {
+     		      command_list[0] = get_history_entry(i);
+                      gtk_list_store_prepend (store, &iter);
+                      gtk_list_store_set (store, &iter,0,command_list[0],-1);
 		 }
-	 }
-     
+	      }
+     } 
      model = GTK_TREE_MODEL(store);
      treeview = gtk_tree_view_new_with_model (model);
      g_object_set_data (G_OBJECT (applet), "tree", treeview);
@@ -418,13 +408,21 @@ show_history_signal(GtkWidget *widget, gpointer data)
                                                        "text", 0, NULL);
      gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
      gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
-     gtk_tree_selection_set_mode( (GtkTreeSelection *)gtk_tree_view_get_selection
+     if (j == 0) {
+          gtk_tree_selection_set_mode( (GtkTreeSelection *)gtk_tree_view_get_selection
+                                (GTK_TREE_VIEW (treeview)),
+                                 GTK_SELECTION_NONE);
+     }
+     else {
+          gtk_tree_selection_set_mode( (GtkTreeSelection *)gtk_tree_view_get_selection
                                 (GTK_TREE_VIEW (treeview)),
                                  GTK_SELECTION_SINGLE);
-     g_signal_connect (G_OBJECT (treeview), "button_press_event",
+          g_signal_connect (G_OBJECT (treeview), "button_press_event",
      		       G_CALLBACK (history_list_button_press_cb), applet);
-     g_signal_connect (G_OBJECT (treeview), "key_press_event",
+          g_signal_connect (G_OBJECT (treeview), "key_press_event",
      		       G_CALLBACK (history_list_key_press_cb), applet);
+     }
+   
      g_object_unref (G_OBJECT (model));
      gtk_container_add(GTK_CONTAINER(scrolled_window),treeview);
      gtk_widget_show (treeview); 
@@ -439,8 +437,7 @@ show_history_signal(GtkWidget *widget, gpointer data)
         y += height;
      	break;
      case PANEL_APPLET_ORIENT_UP:
-        g_print ("up \n");
-     	y -= req.height;
+        y -= req.height;
      	break;
      case PANEL_APPLET_ORIENT_LEFT:
      	x -= req.width;
@@ -472,10 +469,7 @@ show_history_signal(GtkWidget *widget, gpointer data)
      gtk_grab_add(window);
      gtk_widget_grab_focus (treeview);
  
-     /* go on */
      return FALSE;
-     widget = NULL;
-     data = NULL;
 }
 
 static gint 
@@ -496,14 +490,12 @@ file_browser_ok_signal(GtkWidget *widget, gpointer file_select)
 
     /* go on */
     return FALSE;  
-    widget = NULL;
 }
 
-gint 
-show_file_browser_signal(GtkWidget *widget, gpointer data)
+int 
+show_file_browser_signal (GtkWidget   *widget,
+			  PanelApplet *applet)
 {
-    /* FIXME: write this routine */
-    PanelApplet *applet = data;
     GtkWidget *file_select;
 
     /* build file select dialog */
@@ -529,10 +521,7 @@ show_file_browser_signal(GtkWidget *widget, gpointer data)
 
     gtk_widget_show(file_select);
 
-    /* go on */
     return FALSE;
-    widget = NULL;
-    data = NULL;
 }
 
 GtkWidget *
